==> icons-vue-0.0.7.tgz: package/lib/edit--off/16.js <==
'use strict';

var __chunk_1 = require('../chunk-d2faeea1.js');
var iconHelpers = require('@rocketsoftware/icon-helpers');

var virtual_EditOff16 = {
  name: 'EditOff16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(__chunk_1._objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 16 16',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = __chunk_1._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M15 14.3L1.7 1l-.7.7 5 5-4 4V14h3.2l4-4 5 5 .8-.7zM4.8 13H3v-1.8l3.8-3.8 1.8 1.8L4.8 13zm9.9-9.9l-1.8-1.8c-.4-.4-1-.4-1.4 0l-4 4 .7.7L10 4.2 11.8 6 10 7.8l.7.7 4-4c.4-.4.4-1 0-1.4zm-2.2 2.2l-1.8-1.8L12.2 2 14 3.8l-1.5 1.5z"
      }
    }), children]);
  }
};

module.exports = virtual_EditOff16;

==> icons-vue-0.2.8.tgz: package/lib/edit--off/16.js <==
'use strict';

var __chunk_1 = require('../chunk-d2faeea1.js');
var iconHelpers = require('@rocketsoftware/icon-helpers');

var virtual_EditOff16 = {
  name: 'EditOff16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(__chunk_1._objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 16 16',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = __chunk_1._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class[data.class] = true;
    }

    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M15 14.3L1.7 1 1 1.7l5 5-4 4V14h3.2l4-4 5 5L15 14.3zM4.8 13H3v-1.8l3.8-3.8 1.8 1.8L4.8 13zM14.7 3.1L14.7 3.1l-1.8-1.8c-.4-.4-1-.4-1.4 0 0 0 0 0 0 0l0 0-4 4L8.2 6 10 4.2 11.8 6 10 7.8l.7.7 4-4C15.1 4.1 15.1 3.5 14.7 3.1 14.7 3.1 14.7 3.1 14.7 3.1zM12.5 5.3l-1.8-1.8L12.2 2 14 3.8 12.5 5.3z"
      }
    }), children]);
  }
};

module.exports = virtual_EditOff16;
